@@ -41,6 +41,14 @@ class BreakpointExpected(BaseError):
         self.got = got
 
 
+class TrailingBreakpoint(BaseError):
+    template = ("Tag %(tagname)s ends in trailing breakpoint '%(breakpoint)s' without an argument following.")
+
+    def __init__(self, tagname, breakpoint):
+        self.tagname = tagname
+        self.breakpoint = breakpoint
+
+
 class TooManyArguments(BaseError):
     template = "The tag '%(tagname)s' got too many arguments: %(extra)s"
 
